.. _spotify-backend:

*************************************************
:mod:`mopidy.backends.spotify` -- Spotify backend
*************************************************

.. automodule:: mopidy.backends.spotify
    :synopsis: Backend for the Spotify music streaming service
